@@ -1,4 +1,10 @@
 from datetime import datetime, timedelta
+import time
+import pandas as pd
+from sqlalchemy import create_engine
+from sqlalchemy.exc import OperationalError
+import pymysql
+
 
 class hora:
    """
@@ -94,7 +100,7 @@ class mysql:
       self.passx=passx
       self.dbx=dbx
 
-   def mysqlQueryRe(q,intentos=3,sleepStep=1):
+   def mysqlQueryRe(self,q,intentos=3,sleepStep=1):
       looper=0
       intentos=int(intentos)
       valid=False
@@ -103,12 +109,12 @@ class mysql:
               time.sleep(sleepStep*looper)
           looper+=1
           try:
-              df=mysqlQuerySilent(q)
+              df=self.mysqlQuerySilent(q)
               if isinstance(df, pd.DataFrame):
                   valid=True
                   break
           except Exception as e:
-              falla='Err mysql;'+str(e)
+              falla='Err mysql; Check Install sqlalchemy pymysql pandas ;'+str(e)
               out().print(falla)
               nada=0
 
@@ -116,14 +122,14 @@ class mysql:
         out().print('intentos:' + str(looper) + '; df.shape:' + str(df.shape) )
         return {'result':1,'data':df}
       else:
-        out().print('Err mysql; intentos:' + str(looper) + '; df.shape:' + str(df.shape) )
+        out().print('Err mysql; intentos:' + str(looper) )
         return {'result':0,'data':pd.DataFrame()}
 
 
-   def mysqlQuerySilent(query):
+   def mysqlQuerySilent(self,query):
       df='err:'
       try:
-         sqlEngine       = create_engine('mysql+pymysql://'+self.user+':'+self.password+'@'+selfserver)
+         sqlEngine       = create_engine('mysql+pymysql://'+self.userx+':'+self.passx+'@'+self.servidorx)
          dbConnection    = sqlEngine.connect()
          frame           = pd.read_sql(query, dbConnection);
          dbConnection.close()
